@@ -5,6 +5,9 @@ knitr::opts_chunk$set(
 )
 R <- function() knitr::include_graphics("Rlogo.png", dpi = 5000)
 
+## ----echo=FALSE---------------------------------------------------------------
+knitr::include_graphics("hex-hce.png", dpi = 500)
+
 ## ----eval=TRUE----------------------------------------------------------------
 library(hce)
 packageVersion("hce")
